==> POE-Component-Bundle-WebDevelopment-1.001004.tar.gz: POE-Component-Bundle-WebDevelopment-1.001004/README.md <==
# NAME

POE::Component::Bundle::WebDevelopment - a collection of PoCos useful for Web Development

# CONTENTS

This distribution provides the following
[POE::Component](https://metacpan.org/pod/POE::Component) modules:

- [POE::Component::App::PNGCrush](https://metacpan.org/pod/POE::Component::App::PNGCrush) - non-blocking wrapper around [App::PNGCrush](https://metacpan.org/pod/App::PNGCrush)
- [POE::Component::CSS::Minifier](https://metacpan.org/pod/POE::Component::CSS::Minifier) - non-blocking wrapper around [CSS::Minifier](https://metacpan.org/pod/CSS::Minifier) with URI fetching abilities
- [POE::Component::JavaScript::Minifier](https://metacpan.org/pod/POE::Component::JavaScript::Minifier) - non-blocking wrapper around [JavaScript::Minifier](https://metacpan.org/pod/JavaScript::Minifier) with URI fetching abilities
- [POE::Component::Syntax::Highlight::CSS](https://metacpan.org/pod/POE::Component::Syntax::Highlight::CSS) - non-blocking wrapper around [Syntax::Highlight::CSS](https://metacpan.org/pod/Syntax::Highlight::CSS)
- [POE::Component::Syntax::Highlight::HTML](https://metacpan.org/pod/POE::Component::Syntax::Highlight::HTML) - non-blocking wrapper around [Syntax::Highlight::HTML](https://metacpan.org/pod/Syntax::Highlight::HTML)
- [POE::Component::WWW::Alexa::TrafficRank](https://metacpan.org/pod/POE::Component::WWW::Alexa::TrafficRank) - non-blocking wrapper around [WWW::Alexa::TrafficRank](https://metacpan.org/pod/WWW::Alexa::TrafficRank)
- [POE::Component::WWW::Cache::Google](https://metacpan.org/pod/POE::Component::WWW::Cache::Google) - non-blocking wrapper around [WWW::Cache::Google](https://metacpan.org/pod/WWW::Cache::Google)
- [POE::Component::WWW::DoctypeGrabber](https://metacpan.org/pod/POE::Component::WWW::DoctypeGrabber) - non-blocking wrapper around [WWW::DoctypeGrabber](https://metacpan.org/pod/WWW::DoctypeGrabber)
- [POE::Component::WWW::GetPageTitle](https://metacpan.org/pod/POE::Component::WWW::GetPageTitle) - non-blocking wrapper around [WWW::GetPageTitle](https://metacpan.org/pod/WWW::GetPageTitle)
- [POE::Component::WWW::Google::PageRank](https://metacpan.org/pod/POE::Component::WWW::Google::PageRank) - A non-blocking wrapper for [WWW::Google::PageRank](https://metacpan.org/pod/WWW::Google::PageRank)
- [POE::Component::WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/POE::Component::WWW::HTMLTagAttributeCounter) - non-blocking wrapper around [WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/WWW::HTMLTagAttributeCounter)
- [POE::Component::WWW::Lipsum](https://metacpan.org/pod/POE::Component::WWW::Lipsum) - non-blocking wrapper around [WWW::Lipsum](https://metacpan.org/pod/WWW::Lipsum)
- [POE::Component::WWW::WebDevout::BrowserSupportInfo](https://metacpan.org/pod/POE::Component::WWW::WebDevout::BrowserSupportInfo) - non-blocking access to browser support API on [http://webdevout.net](http://webdevout.net)
- [POE::Component::WebService::HtmlKitCom::FavIconFromImage](https://metacpan.org/pod/POE::Component::WebService::HtmlKitCom::FavIconFromImage) - non-blocking wrapper around [WebService::HtmlKitCom::FavIconFromImage](https://metacpan.org/pod/WebService::HtmlKitCom::FavIconFromImage)
- [POE::Component::WebService::Validator::CSS::W3C](https://metacpan.org/pod/POE::Component::WebService::Validator::CSS::W3C) - non-blocking wrapper around [WebService::Validator::HTML::W3C](https://metacpan.org/pod/WebService::Validator::HTML::W3C)
- [POE::Component::WebService::Validator::HTML::W3C](https://metacpan.org/pod/POE::Component::WebService::Validator::HTML::W3C) - a non-blocking POE wrapper around [WebService::Validator::HTML::W3C](https://metacpan.org/pod/WebService::Validator::HTML::W3C)

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each component

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment](https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment/issues](https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-Bundle-WebDevelopment at rt.cpan.org`

# AUTHOR

Zoffix Znet <zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.

==> POE-Component-Bundle-WebDevelopment-2.001001.tar.gz: POE-Component-Bundle-WebDevelopment-2.001001/README.md <==
# NAME

POE::Component::Bundle::WebDevelopment - a collection of PoCos useful for Web Development

# CONTENTS

This distribution provides the following
[POE::Component](https://metacpan.org/pod/POE::Component) modules:

- [POE::Component::App::PNGCrush](https://metacpan.org/pod/POE::Component::App::PNGCrush) - non-blocking wrapper around [App::PNGCrush](https://metacpan.org/pod/App::PNGCrush)
- [POE::Component::CSS::Minifier](https://metacpan.org/pod/POE::Component::CSS::Minifier) - non-blocking wrapper around [CSS::Minifier](https://metacpan.org/pod/CSS::Minifier) with URI fetching abilities
- [POE::Component::JavaScript::Minifier](https://metacpan.org/pod/POE::Component::JavaScript::Minifier) - non-blocking wrapper around [JavaScript::Minifier](https://metacpan.org/pod/JavaScript::Minifier) with URI fetching abilities
- [POE::Component::Syntax::Highlight::CSS](https://metacpan.org/pod/POE::Component::Syntax::Highlight::CSS) - non-blocking wrapper around [Syntax::Highlight::CSS](https://metacpan.org/pod/Syntax::Highlight::CSS)
- [POE::Component::Syntax::Highlight::HTML](https://metacpan.org/pod/POE::Component::Syntax::Highlight::HTML) - non-blocking wrapper around [Syntax::Highlight::HTML](https://metacpan.org/pod/Syntax::Highlight::HTML)
- [POE::Component::WWW::Alexa::TrafficRank](https://metacpan.org/pod/POE::Component::WWW::Alexa::TrafficRank) - non-blocking wrapper around [WWW::Alexa::TrafficRank](https://metacpan.org/pod/WWW::Alexa::TrafficRank)
- [POE::Component::WWW::Cache::Google](https://metacpan.org/pod/POE::Component::WWW::Cache::Google) - non-blocking wrapper around [WWW::Cache::Google](https://metacpan.org/pod/WWW::Cache::Google)
- [POE::Component::WWW::DoctypeGrabber](https://metacpan.org/pod/POE::Component::WWW::DoctypeGrabber) - non-blocking wrapper around [WWW::DoctypeGrabber](https://metacpan.org/pod/WWW::DoctypeGrabber)
- [POE::Component::WWW::GetPageTitle](https://metacpan.org/pod/POE::Component::WWW::GetPageTitle) - non-blocking wrapper around [WWW::GetPageTitle](https://metacpan.org/pod/WWW::GetPageTitle)
- [POE::Component::WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/POE::Component::WWW::HTMLTagAttributeCounter) - non-blocking wrapper around [WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/WWW::HTMLTagAttributeCounter)
- [POE::Component::WWW::Lipsum](https://metacpan.org/pod/POE::Component::WWW::Lipsum) - non-blocking wrapper around [WWW::Lipsum](https://metacpan.org/pod/WWW::Lipsum)
- [POE::Component::WWW::WebDevout::BrowserSupportInfo](https://metacpan.org/pod/POE::Component::WWW::WebDevout::BrowserSupportInfo) - non-blocking access to browser support API on [http://webdevout.net](http://webdevout.net)
- [POE::Component::WebService::HtmlKitCom::FavIconFromImage](https://metacpan.org/pod/POE::Component::WebService::HtmlKitCom::FavIconFromImage) - non-blocking wrapper around [WebService::HtmlKitCom::FavIconFromImage](https://metacpan.org/pod/WebService::HtmlKitCom::FavIconFromImage)
- [POE::Component::WebService::Validator::CSS::W3C](https://metacpan.org/pod/POE::Component::WebService::Validator::CSS::W3C) - non-blocking wrapper around [WebService::Validator::HTML::W3C](https://metacpan.org/pod/WebService::Validator::HTML::W3C)
- [POE::Component::WebService::Validator::HTML::W3C](https://metacpan.org/pod/POE::Component::WebService::Validator::HTML::W3C) - a non-blocking POE wrapper around [WebService::Validator::HTML::W3C](https://metacpan.org/pod/WebService::Validator::HTML::W3C)

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each component

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment](https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment/issues](https://github.com/zoffixznet/POE-Component-Bundle-WebDevelopment/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-Bundle-WebDevelopment at rt.cpan.org`

# AUTHOR

Zoffix Znet &lt;zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.
